@@ -1024,8 +1024,12 @@ void AgendaViewPrivate::insertIncidence(const KCalendarCore::Incidence::Ptr &inc
             // start time. This way is best because it preserves the duration of the event. There are some
             // corner cases where the duration would be messed up, for example a UTC event that when
             // converted to local has dtStart() in day light saving time, but dtEnd() outside DST.
-            // It could create events with 0 duration.
-            const int durationOfFirstOccurrence = event->dtStart().secsTo(event->dtEnd());
+            int durationOfFirstOccurrence = event->dtStart().secsTo(event->dtEnd());
+            if (durationOfFirstOccurrence <= 0) {
+                // https://bugs.kde.org/show_bug.cgi?id=61740
+                // Display 0 duration events as 30 minutes long to have enough space for icons and text
+                durationOfFirstOccurrence = 30 * 60;
+            }
             QTime endTime = startTime.addSecs(durationOfFirstOccurrence);
 
             startY = mAgenda->timeToY(startTime);
@@ -1247,17 +1251,20 @@ void AgendaView::addCalendar(const Akonadi::CollectionCalendar::Ptr &calendar)
 
 void AgendaView::removeCalendar(const Akonadi::CollectionCalendar::Ptr &calendar)
 {
+    if (!calendar || !calendar->collection().isValid()) {
+        return;
+    }
     EventView::removeCalendar(calendar);
 
     auto cal = std::find_if(d->mViewCalendar->mSubCalendars.cbegin(), d->mViewCalendar->mSubCalendars.cend(), [calendar](const auto &subcal) {
-        if (auto akonadiCal = qSharedPointerDynamicCast<AkonadiViewCalendar>(subcal); akonadiCal) {
-            // TODO: FIXME: the pointer-based comparison MUST succeed here, not collection-based comparison!!!
-            return akonadiCal->mCalendar->collection() == calendar->collection();
+        auto s = subcal->getCalendar();
+        if (s) {
+            return s == calendar;
         }
         return false;
     });
 
-    if (cal != d->mViewCalendar->mSubCalendars.end()) {
+    if (*cal && cal != d->mViewCalendar->mSubCalendars.end()) {
         calendar->unregisterObserver(d.get());
         d->mViewCalendar->removeCalendar(*cal);
         setChanges(EventViews::EventView::ResourcesChanged);
